%% 
%% FILE: jep2004.cls
%%
%% USAGE:    \documentclass{jep2004}
%%
%% PURPOSE: LaTeX2e class file for the JEP2004 conference.
%% Adaptated from the JEP98 format
%%
%% ADDITIONAL COMMANDS: \affiliation{}
%% 
%% 
%% Copyright 1993 1994 1995 The LaTeX3 Project and any individual 
%% authors listed elsewhere in this file. 
%% 
%% This system is distributed in the hope that it will be useful, 
%% but WITHOUT ANY WARRANTY; without even the implied warranty of 
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
%% 
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{jep}
\DeclareOption{a4paper}{\paperheight 297mm\paperwidth 210mm }
\DeclareOption{a5paper}
    {\ClassError{proc}{Option `a5paper' not supported}{}}
\DeclareOption{b5paper}
    {\ClassError{proc}{Option `b5paper' not supported}{}}
\DeclareOption{onecolumn}%
    {\ClassError{proc}{Option `onecolumn' not supported}{}}
\DeclareOption{titlepage}%
    {\ClassError{proc}{Option `titlepage' not supported}{}}
\PassOptionsToClass{twocolumn,twoside,a4paper}{article}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
%% \DeclareOption{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass{article}

% ******************************
% Font stuff
% ******************************
\renewcommand\normalsize{%
   \@setfontsize\normalsize\@xpt{11}%
   \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus2\p@
   \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 4\p@ \@plus2\p@ \@minus2\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}
\normalsize
\renewcommand\small{%
   \@setfontsize\small\@viiipt{9.5}%
   \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus\p@
   \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 3\p@ \@plus\p@ \@minus\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}

\renewcommand\footnotesize{%
   \@setfontsize\footnotesize\@viiipt{9.5}%
   \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus\p@
   \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 3\p@ \@plus\p@ \@minus\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}

\renewcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}
\renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
\renewcommand\large{\@setfontsize\large\@xipt{13.6}}
\renewcommand\Large{\@setfontsize\Large\@xiipt{14}}
\renewcommand\LARGE{\@setfontsize\LARGE\@xivpt{18}}
\renewcommand\huge{\@setfontsize\huge\@xxpt{22}}
\renewcommand\Huge{\@setfontsize\Huge\@xxvpt{25}}

\setlength\textfloatsep{14\p@ \@plus 2\p@ \@minus 4\p@}

% ******************************
% 
% ******************************

\pagestyle{empty}

\RequirePackage[bf]{caption}

\setlength\oddsidemargin{0.8in}
\setlength\evensidemargin{0.8in}
\setlength\marginparwidth {0in}
\setlength\textwidth{6.6in}
\setlength\topmargin{0.7in}
\setlength\textheight{10.1in}
\setlength\columnsep{0.2in}
\setlength\headheight{0in}
\setlength\headsep{0in}
\setlength\hoffset{-1.0in}
\setlength\voffset{-1.0in}
\setlength\parskip{9pt}
\setlength\parindent{0pt}

\def\maketitle{\par
 \begingroup
   \renewcommand\thefootnote{\fnsymbol{footnote}}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
     \long\def\@makefntext##1{\parindent 1em\noindent
             \hb@xt@1.8em{%
                 \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
   \twocolumn[\@maketitle]%
   \@thanks
 \endgroup
 \setcounter{footnote}{0}%
 \let\maketitle\relax
 \let\@maketitle\relax
 \gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\thanks\relax}

\newcommand{\IC@affiliation}{}
\newcommand{\affiliation}[1] {\renewcommand{\IC@affiliation}{#1}}

\def\@maketitle{%
  \vbox to 2.25in{%
    \hsize\textwidth
    \linewidth\hsize
    \vfil
    \centering
    {\LARGE\bfseries \@title \par}
    \vskip 0.5em
    {\Large\itshape \begin{tabular}[t]{c} \@author \end{tabular}\par}
    \vskip 0.5em
    {\normalsize \begin{tabular}[t]{c} \IC@affiliation \end{tabular} \par} 
    \vskip 1em
   \vfil}}
\def\copyrightspace{%
  \footnotetext[0]{\mbox{}\vrule \@height 97\p@ \@width \z@}}

\renewcommand{\refname}{Bibliographie}
\def\@biblabel#1{[#1]}
\renewenvironment{thebibliography}[1]
     {\section*{\refname
        \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy\clubpenalty4000\widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}


\renewcommand{\@seccntformat}[1]{{\csname the#1\endcsname}.\quad}
\setcounter{secnumdepth}{2}
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {0pt}%
                                   {.1pt}%
                                   {\normalfont\Large\sc\bfseries\centering}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {0pt}%
                                     {.1pt}%
                                     {\normalfont\large\itshape\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {0pt}
                                     {-1.5ex}%
                                     {\normalfont\bfseries}}
\renewcommand{\abstractname}{Abstract}
\renewenvironment{abstract}%
  {\section*{ABSTRACT}}{\par}

\endinput
